<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'info_compresseur_titre' => 'Plejbonigoj kaj densigoj',
	'info_question_activer_compactage_css' => 'CSS',
	'info_question_activer_compactage_js' => 'Skriptoj',
	'item_compresseur_closure' => 'Uzi Google Closure Compiler [eksperimenta]',
	'item_compresseur_css' => 'Aktivigi la densigon de la stilfolio (CSS)',
	'item_compresseur_js' => 'Aktivigi la densigon de la skriptoj (ĝavoskripto)',

	// T
	'texte_compacter_avertissement' => 'Atentu ne ebligi tiujn opciojn dum disvolviĝo de via retejo : la densigaj elementoj perdas ĉian legeblecon.',
	'texte_compacter_script_css' => 'SPIP povas densigi ĝavoskriptaj skriptoj kaj CSS stilfolioj, por registri ilin en statikaj dosieroj. Tio plirapidigas la afiŝon de la retejo.',
	'titre_compacter_script_css' => 'Densigo de skriptojn kaj CSS'
);

?>
